<?php

namespace apexl\Config;

final readonly class ConfigurationMock implements ConfigurationInterface
{
    public function __construct(private array $data = []) {}

    public function get(string $key): mixed
    {
        return $this->data[$key];
    }

    public function all(): array
    {
        return $this->data;
    }

    public function has(string $key): bool
    {
        return array_key_exists($key, $this->data);
    }
}