<?php

declare(strict_types=1);

namespace apexl\Config;

use apexl\Config\Exceptions\MissingConfigException;

interface ConfigurationInterface
{
    /**
     * @throws MissingConfigException
     */
    public function get(string $key): mixed;

    public function has(string $key): bool;

    public function all(): array;
}